@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2023 Oracle and/or its affiliates.
+ * Copyright (C) 2013-2024 Oracle and/or its affiliates.
  * This file is based on ast_mode.c
  * Copyright 2012 Red Hat Inc.
  * Parts based on xf86-video-ast
@@ -52,8 +52,8 @@
 #include "vboxvideo.h"
 
 static int vbox_cursor_set2(struct drm_crtc *crtc, struct drm_file *file_priv,
-			    u32 handle, u32 width, u32 height,
-			    s32 hot_x, s32 hot_y);
+				u32 handle, u32 width, u32 height,
+				s32 hot_x, s32 hot_y);
 static int vbox_cursor_move(struct drm_crtc *crtc, int x, int y);
 
 /**
@@ -61,7 +61,7 @@ static int vbox_cursor_move(struct drm_crtc *crtc, int x, int y);
  * mode set and tell the host we support advanced graphics functions.
  */
 static void vbox_do_modeset(struct drm_crtc *crtc,
-			    const struct drm_display_mode *mode)
+				const struct drm_display_mode *mode)
 {
 	struct vbox_crtc *vbox_crtc = to_vbox_crtc(crtc);
 	struct vbox_private *vbox;
@@ -92,8 +92,8 @@ static void vbox_do_modeset(struct drm_crtc *crtc,
 	 * screen is programmed this way, so try to fake it.
 	 */
 	if (vbox_crtc->crtc_id == 0 && crtc->enabled &&
-	    vbox_crtc->fb_offset / pitch < 0xffff - crtc->y &&
-	    vbox_crtc->fb_offset % (bpp / 8) == 0)
+		vbox_crtc->fb_offset / pitch < 0xffff - crtc->y &&
+		vbox_crtc->fb_offset % (bpp / 8) == 0)
 		VBoxVideoSetModeRegisters(
 			width, height, pitch * 8 / bpp,
 #if RTLNX_VER_MIN(4,11,0) || RTLNX_RHEL_MAJ_PREREQ(7,5)
@@ -176,7 +176,7 @@ static bool vbox_set_up_input_mapping(struct vbox_private *vbox)
 	}
 	if (single_framebuffer) {
 		list_for_each_entry(crtci, &vbox->dev->mode_config.crtc_list,
-				    head) {
+					head) {
 			if (to_vbox_crtc(crtci)->crtc_id != 0)
 				continue;
 
@@ -186,20 +186,20 @@ static bool vbox_set_up_input_mapping(struct vbox_private *vbox)
 			vbox->input_mapping_width = CRTC_FB(crtci)->width;
 			vbox->input_mapping_height = CRTC_FB(crtci)->height;
 			return old_single_framebuffer !=
-			       vbox->single_framebuffer;
+				   vbox->single_framebuffer;
 		}
 	}
 	/* Otherwise calculate the total span of all screens. */
 	list_for_each_entry(connectori, &vbox->dev->mode_config.connector_list,
-			    head) {
+				head) {
 		struct vbox_connector *vbox_connector =
-		    to_vbox_connector(connectori);
+			to_vbox_connector(connectori);
 		struct vbox_crtc *vbox_crtc = vbox_connector->vbox_crtc;
 
 		width = max_t(u16, width, vbox_crtc->x_hint +
 					  vbox_connector->mode_hint.width);
 		height = max_t(u16, height, vbox_crtc->y_hint +
-					    vbox_connector->mode_hint.height);
+						vbox_connector->mode_hint.height);
 	}
 
 	vbox->single_framebuffer = false;
@@ -260,7 +260,7 @@ static int vbox_crtc_set_base(struct drm_crtc *crtc,
 		struct drm_crtc *crtci;
 
 		list_for_each_entry(crtci, &vbox->dev->mode_config.crtc_list,
-				    head) {
+					head) {
 			vbox_do_modeset(crtci, &crtci->mode);
 		}
 	}
@@ -269,9 +269,9 @@ static int vbox_crtc_set_base(struct drm_crtc *crtc,
 }
 
 static int vbox_crtc_mode_set(struct drm_crtc *crtc,
-			      struct drm_display_mode *mode,
-			      struct drm_display_mode *adjusted_mode,
-			      int x, int y, struct drm_framebuffer *old_fb)
+				  struct drm_display_mode *mode,
+				  struct drm_display_mode *adjusted_mode,
+				  int x, int y, struct drm_framebuffer *old_fb)
 {
 	struct vbox_private *vbox = crtc->dev->dev_private;
 	int ret = vbox_crtc_set_base(crtc, old_fb, CRTC_FB(crtc), x, y);
@@ -288,16 +288,16 @@ static int vbox_crtc_mode_set(struct drm_crtc *crtc,
 }
 
 static int vbox_crtc_page_flip(struct drm_crtc *crtc,
-			       struct drm_framebuffer *fb,
+				   struct drm_framebuffer *fb,
 #if RTLNX_VER_MIN(4,12,0) || RTLNX_RHEL_MAJ_PREREQ(7,5)
-			       struct drm_pending_vblank_event *event,
-			       u32 page_flip_flags,
-			       struct drm_modeset_acquire_ctx *ctx)
+				   struct drm_pending_vblank_event *event,
+				   u32 page_flip_flags,
+				   struct drm_modeset_acquire_ctx *ctx)
 #elif RTLNX_VER_MIN(3,12,0) || RTLNX_RHEL_MAJ_PREREQ(7,0)
-			       struct drm_pending_vblank_event *event,
-			       u32 page_flip_flags)
+				   struct drm_pending_vblank_event *event,
+				   u32 page_flip_flags)
 #else
-			       struct drm_pending_vblank_event *event)
+				   struct drm_pending_vblank_event *event)
 #endif
 {
 	struct vbox_private *vbox = crtc->dev->dev_private;
@@ -426,7 +426,7 @@ static struct drm_encoder *drm_encoder_find(struct drm_device *dev, u32 id)
 #endif
 
 static struct drm_encoder *vbox_best_single_encoder(struct drm_connector
-						    *connector)
+						*connector)
 {
 #if RTLNX_VER_MIN(5,5,0) || RTLNX_RHEL_MIN(8,3) || RTLNX_SUSE_MAJ_PREREQ(15,3)
 		struct drm_encoder *encoder;
@@ -457,8 +457,8 @@ static void vbox_encoder_dpms(struct drm_encoder *encoder, int mode)
 }
 
 static bool vbox_mode_fixup(struct drm_encoder *encoder,
-			    const struct drm_display_mode *mode,
-			    struct drm_display_mode *adjusted_mode)
+				const struct drm_display_mode *mode,
+				struct drm_display_mode *adjusted_mode)
 {
 	return true;
 }
@@ -486,7 +486,7 @@ static const struct drm_encoder_helper_funcs vbox_enc_helper_funcs = {
 };
 
 static struct drm_encoder *vbox_encoder_init(struct drm_device *dev,
-					     unsigned int i)
+						unsigned int i)
 {
 	struct vbox_encoder *vbox_encoder;
 
@@ -517,33 +517,33 @@ static void vbox_set_edid(struct drm_connector *connector, int width,
 {
 	enum { EDID_SIZE = 128 };
 	unsigned char edid[EDID_SIZE] = {
-		0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00,	/* header */
-		0x58, 0x58,	/* manufacturer (VBX) */
-		0x00, 0x00,	/* product code */
-		0x00, 0x00, 0x00, 0x00,	/* serial number goes here */
-		0x01,		/* week of manufacture */
-		0x00,		/* year of manufacture */
-		0x01, 0x03,	/* EDID version */
-		0x80,		/* capabilities - digital */
-		0x00,		/* horiz. res in cm, zero for projectors */
-		0x00,		/* vert. res in cm */
-		0x78,		/* display gamma (120 == 2.2). */
-		0xEE,		/* features (standby, suspend, off, RGB, std */
+		0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, /* header */
+		0x58, 0x58, /* manufacturer (VBX) */
+		0x00, 0x00, /* product code */
+		0x00, 0x00, 0x00, 0x00, /* serial number goes here */
+		0x01,       /* week of manufacture */
+		0x00,       /* year of manufacture */
+		0x01, 0x03, /* EDID version */
+		0x80,       /* capabilities - digital */
+		0x00,       /* horiz. res in cm, zero for projectors */
+		0x00,       /* vert. res in cm */
+		0x78,       /* display gamma (120 == 2.2). */
+		0xEE,       /* features (standby, suspend, off, RGB, std */
 				/* colour space, preferred timing mode) */
 		0xEE, 0x91, 0xA3, 0x54, 0x4C, 0x99, 0x26, 0x0F, 0x50, 0x54,
 		/* chromaticity for standard colour space. */
-		0x00, 0x00, 0x00,	/* no default timings */
+		0x00, 0x00, 0x00,   /* no default timings */
 		0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
-		    0x01, 0x01,
-		0x01, 0x01, 0x01, 0x01,	/* no standard timings */
+			0x01, 0x01,
+		0x01, 0x01, 0x01, 0x01, /* no standard timings */
 		0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x06, 0x00, 0x02, 0x02,
-		    0x02, 0x02,
+			0x02, 0x02,
 		/* descriptor block 1 goes below */
 		0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 		/* descriptor block 2, monitor ranges */
 		0x00, 0x00, 0x00, 0xFD, 0x00,
 		0x00, 0xC8, 0x00, 0xC8, 0x64, 0x00, 0x0A, 0x20, 0x20, 0x20,
-		    0x20, 0x20,
+			0x20, 0x20,
 		/* 0-200Hz vertical, 0-200KHz horizontal, 1000MHz pixel clock */
 		0x20,
 		/* descriptor block 3, monitor name */
@@ -555,8 +555,8 @@ static void vbox_set_edid(struct drm_connector *connector, int width,
 		0x0A, 0x20, 0x20, 0x20, 0x20, 0x20,
 		0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
 		0x20,
-		0x00,		/* number of extensions */
-		0x00		/* checksum goes here */
+		0x00,       /* number of extensions */
+		0x00        /* checksum goes here */
 	};
 	int clock = (width + 6) * (height + 6) * 60 / 10000;
 	unsigned int i, sum = 0;
@@ -604,7 +604,7 @@ static int vbox_get_modes(struct drm_connector *connector)
 	 * capability.
 	 */
 	hgsmi_report_flags_location(vbox->guest_pool, GUEST_HEAP_OFFSET(vbox) +
-				    HOST_FLAGS_OFFSET);
+					HOST_FLAGS_OFFSET);
 	if (vbox_connector->vbox_crtc->crtc_id == 0)
 		vbox_report_caps(vbox);
 	if (!vbox->initial_mode_queried) {
@@ -624,7 +624,7 @@ static int vbox_get_modes(struct drm_connector *connector)
 	preferred_height = vbox_connector->mode_hint.height ?
 			   vbox_connector->mode_hint.height : 768;
 	mode = drm_cvt_mode(connector->dev, preferred_width, preferred_height,
-			    60, false, false, false);
+				60, false, false, false);
 	if (mode) {
 		mode->type |= DRM_MODE_TYPE_PREFERRED;
 		drm_mode_probed_add(connector, mode);
@@ -682,7 +682,7 @@ vbox_connector_detect(struct drm_connector *connector, bool force)
 	vbox_connector = to_vbox_connector(connector);
 
 	return vbox_connector->mode_hint.disconnected ?
-	    connector_status_disconnected : connector_status_connected;
+		connector_status_disconnected : connector_status_connected;
 }
 
 static int vbox_fill_modes(struct drm_connector *connector, u32 max_x,
@@ -716,8 +716,8 @@ static const struct drm_connector_funcs vbox_connector_funcs = {
 };
 
 static int vbox_connector_init(struct drm_device *dev,
-			       struct vbox_crtc *vbox_crtc,
-			       struct drm_encoder *encoder)
+				   struct vbox_crtc *vbox_crtc,
+				   struct drm_encoder *encoder)
 {
 	struct vbox_connector *vbox_connector;
 	struct drm_connector *connector;
@@ -793,7 +793,7 @@ void vbox_mode_fini(struct drm_device *dev)
  * if the corresponding alpha value in the ARGB image is greater than 0xF0.
  */
 static void copy_cursor_image(u8 *src, u8 *dst, u32 width, u32 height,
-			      size_t mask_size)
+				  size_t mask_size)
 {
 	size_t line_size = (width + 7) / 8;
 	u32 i, j;
@@ -806,8 +806,8 @@ static void copy_cursor_image(u8 *src, u8 *dst, u32 width, u32 height,
 }
 
 static int vbox_cursor_set2(struct drm_crtc *crtc, struct drm_file *file_priv,
-			    u32 handle, u32 width, u32 height,
-			    s32 hot_x, s32 hot_y)
+				u32 handle, u32 width, u32 height,
+				s32 hot_x, s32 hot_y)
 {
 	struct vbox_private *vbox = crtc->dev->dev_private;
 	struct vbox_crtc *vbox_crtc = to_vbox_crtc(crtc);
@@ -828,21 +828,21 @@ static int vbox_cursor_set2(struct drm_crtc *crtc, struct drm_file *file_priv,
 		/* Hide cursor. */
 		vbox_crtc->cursor_enabled = false;
 		list_for_each_entry(crtci, &vbox->dev->mode_config.crtc_list,
-				    head) {
+					head) {
 			if (to_vbox_crtc(crtci)->cursor_enabled)
 				cursor_enabled = true;
 			}
 
 		if (!cursor_enabled)
 			hgsmi_update_pointer_shape(vbox->guest_pool, 0, 0, 0,
-						   0, 0, NULL, 0);
+						0, 0, NULL, 0);
 		return 0;
 	}
 
 	vbox_crtc->cursor_enabled = true;
 
 	if (width > VBOX_MAX_CURSOR_WIDTH || height > VBOX_MAX_CURSOR_HEIGHT ||
-	    width == 0 || height == 0)
+		width == 0 || height == 0)
 		return -EINVAL;
 	ret = hgsmi_query_conf(vbox->guest_pool,
 				VBOX_VBVA_CONF32_CURSOR_CAPABILITIES, &caps);
@@ -951,9 +951,9 @@ static int vbox_cursor_move(struct drm_crtc *crtc, int x, int y)
 {
 	struct vbox_private *vbox = crtc->dev->dev_private;
 	s32 crtc_x =
-	    vbox->single_framebuffer ? crtc->x : to_vbox_crtc(crtc)->x_hint;
+		vbox->single_framebuffer ? crtc->x : to_vbox_crtc(crtc)->x_hint;
 	s32 crtc_y =
-	    vbox->single_framebuffer ? crtc->y : to_vbox_crtc(crtc)->y_hint;
+		vbox->single_framebuffer ? crtc->y : to_vbox_crtc(crtc)->y_hint;
 	int ret;
 
 	x += vbox->cursor_hot_x;
@@ -963,8 +963,8 @@ static int vbox_cursor_move(struct drm_crtc *crtc, int x, int y)
 		y + crtc_y >= vbox->input_mapping_width ||
 		vbox->cursor_data_size == 0)
 		return 0;
-	ret = hgsmi_cursor_position(vbox->guest_pool, true, x + crtc_x,
-					 y + crtc_y, NULL, NULL);
+	ret = VBoxHGSMIReportCursorPosition(vbox->guest_pool, true, x + crtc_x,
+						y + crtc_y, NULL, NULL);
 	return ret == VINF_SUCCESS ? 0 : ret == VERR_NO_MEMORY ? -ENOMEM : ret ==
 		VERR_NOT_SUPPORTED ? -EBUSY : -EINVAL;
 }
